scroll_restoration library
Classes
- ScrollRestoration
- Wrap any scrollable widget to remember its scroll offset.
- ScrollRestorationState
- State for ScrollRestoration.
Typedefs
- ScrollRestorationBuilder = Widget Function(BuildContext, ScrollController)
- A function that builds a widget with a ScrollController.